==> kadu_0.5.0.orig.tar.gz: kadu/modules/default_sms/translations/default_sms_fr.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>@default</name>
    <message>
        <source>Password</source>
        <translation>Mot de passe </translation>
    </message>
    <message>
        <source>SMS Era Gateway</source>
        <translation>Portail SMS Era GSM</translation>
    </message>
    <message>
        <source>Type of gateway</source>
        <translation>Type de portail</translation>
    </message>
    <message>
        <source>User ID (48xxxxxxxxx)</source>
        <translation>ID utilisateur(48xxxxxxxxx)</translation>
    </message>
</context>
<context>
    <name>SmsEraGateway</name>
    <message>
        <source>Provider gateway results page looks strange. SMS was probably NOT sent.</source>
        <translation>La page de résultats du Portail de fournisseur semble être étrange.Probablement le SMS n&apos;a pas été  envoyé.</translation>
    </message>
    <message>
        <source>Error: </source>
        <translation>Erreur:</translation>
    </message>
    <message>
        <source>No error</source>
        <translation>Sans erreur</translation>
    </message>
    <message>
        <source>System failure</source>
        <translation>Problème de système</translation>
    </message>
    <message>
        <source>Unauthorised user</source>
        <translation>Utilisateur non autorisé</translation>
    </message>
    <message>
        <source>Access forbidden</source>
        <translation>L&apos;Access bloqué</translation>
    </message>
    <message>
        <source>Syntax error</source>
        <translation>Erreur de syntaxe</translation>
    </message>
    <message>
        <source>Limit of the sms run-down</source>
        <translation>Limite SMS epuisé</translation>
    </message>
    <message>
        <source>Message too long</source>
        <translation>Message trop long</translation>
    </message>
    <message>
        <source>Wrong receiver address</source>
        <translation>Adresse de receveur non correct</translation>
    </message>
    <message>
        <source>Unknown error (%1)</source>
        <translation>Erreur inconnu (%1)</translation>
    </message>
    <message>
        <source>You don&apos;t have enough tokens</source>
        <translation>Vous n&apos;avez pas assez de jetons pour les SMS</translation>
    </message>
    <message>
        <source>Number of SMS&apos; left on Sponsored Era Gateway: </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SmsGatewaySlots</name>
    <message>
        <source>Sponsored</source>
        <translation>Sponsorisé</translation>
    </message>
    <message>
        <source>OmnixMultimedia</source>
        <translation>OmnixMultimedia</translation>
    </message>
</context>
<context>
    <name>SmsOrangeGateway</name>
    <message>
        <source>Provider gateway page looks strange. It&apos;s probably temporary disabled
or has beed changed too much to parse it correctly.</source>
        <translation>Le portail de fournisseur SMS indiqué est inaccessible
Probablement elle est inactive ou le fournisseur a changé le principe d&apos;access.
</translation>
    </message>
    <message>
        <source>You exceeded your daily limit</source>
        <translation>Limite SMS envoyés depassée</translation>
    </message>
    <message>
        <source>Text from the picture is incorrect</source>
        <translation>Le texte provenant d&apos;image est enregistré de façon non correcte</translation>
    </message>
    <message>
        <source>The receiver has to enable SMS STANDARD service</source>
        <translation>Le receveur  du message n&apos;a pas activé le service SMS STANDARD</translation>
    </message>
    <message>
        <source>Provider gateway results page looks strange. SMS was probably NOT sent.</source>
        <translation>Le portail a renvoyé une réponse étrange.SMS n&apos;a pas été envoyé.</translation>
    </message>
</context>
<context>
    <name>SmsPlusGateway</name>
    <message>
        <source>Provider gateway page looks strange. It&apos;s probably temporary disabled
or has beed changed too much to parse it correctly.</source>
        <translation>La page du Portail de fournisseur semble étrange.Probablement il s&apos;agit d&apos;une ligne provisoire 
ou il est impossible de l&apos;analyser correctement.
</translation>
    </message>
    <message>
        <source>Provider gateway results page looks strange. SMS was probably NOT sent.</source>
        <translation>La page du Portail de fournisseur semble être étrange.Probablement le SMS n&apos;a pas été  envoyé.</translation>
    </message>
    <message>
        <source>Limits have been exceeded, try again later.</source>
        <translation>Le limite est dépassé, veuillez essayer plus tard.</translation>
    </message>
</context>
</TS>

==> kadu_0.6.0.2.orig.tar.gz: kadu/modules/default_sms/translations/default_sms_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1">
<context>
    <name>@default</name>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="4"/>
        <source>SMS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="8"/>
        <source>General</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="12"/>
        <source>Gateways</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="15"/>
        <source>SMS Era Gateway</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="18"/>
        <source>Sponsored</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="21"/>
        <source>OmnixMultimedia</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="31"/>
        <source>User ID (48xxxxxxxxx)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="34"/>
        <source>Password</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SmsEraGateway</name>
    <message>
        <location filename="../default_sms.cpp" line="344"/>
        <source>Provider gateway results page looks strange. SMS was probably NOT sent.</source>
        <translation>La page de résultats du Portail de fournisseur semble être étrange.Probablement le SMS n&apos;a pas été  envoyé.</translation>
    </message>
    <message>
        <location filename="../default_sms.cpp" line="340"/>
        <source>Error: </source>
        <translation>Erreur:</translation>
    </message>
    <message>
        <location filename="../default_sms.cpp" line="353"/>
        <source>No error</source>
        <translation>Sans erreur</translation>
    </message>
    <message>
        <location filename="../default_sms.cpp" line="354"/>
        <source>System failure</source>
        <translation>Problème de système</translation>
    </message>
    <message>
        <location filename="../default_sms.cpp" line="355"/>
        <source>Unauthorised user</source>
        <translation>Utilisateur non autorisé</translation>
    </message>
    <message>
        <location filename="../default_sms.cpp" line="356"/>
        <source>Access forbidden</source>
        <translation>L&apos;Access bloqué</translation>
    </message>
    <message>
        <location filename="../default_sms.cpp" line="357"/>
        <source>Syntax error</source>
        <translation>Erreur de syntaxe</translation>
    </message>
    <message>
        <location filename="../default_sms.cpp" line="358"/>
        <source>Limit of the sms run-down</source>
        <translation>Limite SMS epuisé</translation>
    </message>
    <message>
        <location filename="../default_sms.cpp" line="360"/>
        <source>Message too long</source>
        <translation>Message trop long</translation>
    </message>
    <message>
        <location filename="../default_sms.cpp" line="359"/>
        <source>Wrong receiver address</source>
        <translation>Adresse de receveur non correct</translation>
    </message>
    <message>
        <location filename="../default_sms.cpp" line="363"/>
        <source>Unknown error (%1)</source>
        <translation>Erreur inconnu (%1)</translation>
    </message>
    <message>
        <location filename="../default_sms.cpp" line="361"/>
        <source>You don&apos;t have enough tokens</source>
        <translation>Vous n&apos;avez pas assez de jetons pour les SMS</translation>
    </message>
    <message>
        <location filename="../default_sms.cpp" line="333"/>
        <source>Number of SMS&apos; left on Sponsored Era Gateway: </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SmsOrangeGateway</name>
    <message>
        <location filename="../default_sms.cpp" line="105"/>
        <source>Provider gateway page looks strange. It&apos;s probably temporary disabled
or has beed changed too much to parse it correctly.</source>
        <translation>Le portail de fournisseur SMS indiqué est inaccessible
Probablement elle est inactive ou le fournisseur a changé le principe d&apos;access.
</translation>
    </message>
    <message>
        <location filename="../default_sms.cpp" line="130"/>
        <source>You exceeded your daily limit</source>
        <translation>Limite SMS envoyés depassée</translation>
    </message>
    <message>
        <location filename="../default_sms.cpp" line="136"/>
        <source>Text from the picture is incorrect</source>
        <translation>Le texte provenant d&apos;image est enregistré de façon non correcte</translation>
    </message>
    <message>
        <location filename="../default_sms.cpp" line="142"/>
        <source>The receiver has to enable SMS STANDARD service</source>
        <translation>Le receveur  du message n&apos;a pas activé le service SMS STANDARD</translation>
    </message>
    <message>
        <location filename="../default_sms.cpp" line="153"/>
        <source>Provider gateway results page looks strange. SMS was probably NOT sent.</source>
        <translation>Le portail a renvoyé une réponse étrange.SMS n&apos;a pas été envoyé.</translation>
    </message>
</context>
<context>
    <name>SmsPlusGateway</name>
    <message>
        <location filename="../default_sms.cpp" line="234"/>
        <source>Provider gateway page looks strange. It&apos;s probably temporary disabled
or has beed changed too much to parse it correctly.</source>
        <translation>La page du Portail de fournisseur semble étrange.Probablement il s&apos;agit d&apos;une ligne provisoire 
ou il est impossible de l&apos;analyser correctement.
</translation>
    </message>
    <message>
        <location filename="../default_sms.cpp" line="259"/>
        <source>Provider gateway results page looks strange. SMS was probably NOT sent.</source>
        <translation>La page du Portail de fournisseur semble être étrange.Probablement le SMS n&apos;a pas été  envoyé.</translation>
    </message>
    <message>
        <location filename="../default_sms.cpp" line="252"/>
        <source>Limits have been exceeded, try again later.</source>
        <translation>Le limite est dépassé, veuillez essayer plus tard.</translation>
    </message>
</context>
</TS>
